Live Image Viewer — LaVue 2.76.0 documentation

# Live Image Viewer

LaVue is a simple implementation of a live viewer front end. It is supposed to show a live image view from xray-detectors at PETRA3 @ desy.de, e.g. `Pilatus`, `Lambda`, `Eiger`, `PerkinElmer`, `PCO`, `LimaCCD`, and others.

Authors: Christoph Rosemann <christoph.rosemann at desy.de>, Jan Kotański <jan.kotanski at desy.de>, André Rothkirch <andre.rothkirch at desy.de>

# Contents

- Installation
  - From sources
  - Debian packages
  - From pip
- Start the Viewer
  - Start the Viewer in the expert mode
  - Launching options
- GUI User Guide
  - Image Sources and stitching images
    - Hirda
    - HTTP response
    - Tango Attribute
    - Tango Events
    - Tango File
    - DOOCS property
    - ZMQ stream
    - NeXus File
    - Tine Property
    - Epics PV
    - ASAPO
    - Test
  - Range Window and Down-Sampling
  - LaVue Filters
  - Memory Buffer
  - Image Preparation
  - Scaling and Display Levels
  - Image Statistics
  - 2D Plot
  - Specialized Tools
    - Intensity Tool
    - ROI Tool
    - LineCut Tool
    - Angle/Q Tool
    - MoveMotor Tool
    - MeshScan Tool
    - 1d-Plot Tool
    - Projections Tool
    - Q+ROI+Proj Tool
    - Maxima Tool
    - Parameters Tool
    - Diffractogram Tool
  - Images from FileSystem
  - Configuration
    - General Settings
    - Layout Settings
    - Hidra/HTTP/ZMQ/ASAPO/NeXus Image Source Settings
    - Tango/DOOCS/Tine/Epics Image Source Settings
    - Filter plugins settings
- LaVueController server
  - Attributes
  - Properties
- LaVue Monitor
- ZMQ Stream server examples
- Filter plugins
- Developer Guide
  - API reference
    - lavuelib package

# Indices and tables

- Index

- Module Index

- Search Page

# Further reading

`LaVue Documentation`: LaVue
`LavueController` Tango Server API: LaVueController documentation
`Conflunce` page: https://confluence.desy.de/display/FSEC/LaVue+-+Live+Image+Viewer
`Github` repository: https://github.com/lavue-org/lavue